@@ -3,7 +3,7 @@ package Protocol::DBus;
 use strict;
 use warnings;
 
-our $VERSION = '0.11_03';
+our $VERSION = '0.15_01';
 
 =encoding utf8
 
@@ -34,23 +34,35 @@ For blocking I/O:
 
     my $msg = $dbus->get_message();
 
-For non-blocking I/O, it is recommended to use either
-L<Protocol::DBus::Client::IOAsync> (for L<IO::Async>) or
-L<Protocol::DBus::Client::AnyEvent> (for L<AnyEvent>).
+For non-blocking I/O, it is recommended to use an event loop.
+This distribution includes some connectors to simplify that work:
+
+=over
+
+=item * L<Protocol::DBus::Client::IOAsync> (for L<IO::Async>)
+
+=item * L<Protocol::DBus::Client::Mojo> (for L<Mojolicious>)
+
+=item * L<Protocol::DBus::Client::AnyEvent> (for L<AnyEvent>)
+
+=back
 
 Example:
 
     my $loop = IO::Async::Loop->new();
 
-    Protcol::DBus::Client::IOAsync::login_session($loop)->then(
+    my $dbus = Protcol::DBus::Client::IOAsync::login_session($loop);
+
+    $dbus->initialize()->then(
         sub ($dbus) {
-            $dbus->send_call( … );
+            return $dbus->send_call( … );  # same arguments as above
         },
     )->finally( sub { $loop->stop() } );
 
     $loop->run();
 
-See below for an example using a manually-written event loop.
+You can also interface with a manually-written event loop.
+See L<the example|/EXAMPLE USING MANUALLY-WRITTEN EVENT LOOP> below.
 
 =head1 DESCRIPTION
 
@@ -63,8 +75,8 @@ This is fine, of course, if all you want to do is, e.g., replace
 an invocation of C<gdbus> or C<dbus-send> with pure Perl.
 
 If you want an interface that mimics D-Bus’s actual object system,
-you’ll need to implement it yourself or to look elsewhere.
-(See L</SEE ALSO> below.)
+you’ll need to implement it yourself or use something like L<Net::DBus>.
+(See L</DIFFERENCES FROM Net::DBus> below.)
 
 =head1 STATUS
 
@@ -79,6 +91,42 @@ See L<Protocol::DBus::Client> and the above samples for a starting point.
 
 Also see the distribution’s F<examples/> directory.
 
+=head1 DIFFERENCES FROM Net::DBus
+
+L<Net::DBus> is an XS binding to
+L<libdbus|https://www.freedesktop.org/wiki/Software/dbus/>,
+the reference D-Bus implementation. It is CPAN’s most mature D-Bus
+implementation.
+
+There are several reasons why you might prefer this module instead,
+though, such as:
+
+=over
+
+=item * Net::DBus discerns how to send a method call via D-Bus introspection.
+While handy, this costs extra network overhead and requires an XML parser.
+With Protocol::DBus you give a signature directly to send a method call,
+
+=item * Protocol::DBus can work smoothly with any event system you like,
+including custom-written ones. (The distribution ships with connectors for
+three popular ones.) Net::DBus, on the other hand, expects you to use its
+own event loop, L<Net::DBus::Reactor>.
+
+=item * Protocol::DBus has a considerably lighter memory footprint.
+
+=item * Protocol::DBus is pure Perl, so on most OSes you can fat-pack it
+for easy distribution.
+
+=item * Protocol::DBus exposes a simpler API.
+
+=back
+
+Of course, there are tradeoffs: most notably, Protocol::DBus’s API is
+simpler because it doesn’t attempt to implement D-Bus’s object system.
+(You never B<need> the object system, but it can be a useful abstraction.)
+An XS-powered D-Bus library is also likely to outperform a
+pure-Perl one, introspection overhead notwithstanding. YMMV. BYOB.
+
 =head1 NOTES
 
 =over
@@ -104,12 +152,6 @@ send local socket credentials without using C<sendmsg(2)>.
 
 =back
 
-=head1 SEE ALSO
-
-The most mature, stable D-Bus implementation in Perl is L<Net::DBus>,
-an XS binding to L<libdbus|https://www.freedesktop.org/wiki/Software/dbus/>,
-the reference D-Bus implementation.
-
 =head1 EXAMPLE USING MANUALLY-WRITTEN EVENT LOOP
 
     my $dbus = Protcol::DBus::Client::system();
